@@ -1,7 +1,7 @@
 %
 %% %CopyrightBegin%
 %%
-%% Copyright Ericsson AB 2018-2018. All Rights Reserved.
+%% Copyright Ericsson AB 2018-2020. All Rights Reserved.
 %%
 %% Licensed under the Apache License, Version 2.0 (the "License");
 %% you may not use this file except in compliance with the License.
@@ -123,19 +123,19 @@ suite_map_to_openssl_str(#{key_exchange := rsa = Kex,
 suite_map_to_openssl_str(#{key_exchange := Kex,
                            cipher := chacha20_poly1305 = Cipher,
                            mac := aead}) ->
-    openssl_suite_start(string:to_upper(atom_to_list(Kex))) 
+    openssl_suite_start(string:to_upper(atom_to_list(Kex)), Cipher) 
         ++  openssl_cipher_name(Kex, string:to_upper(atom_to_list(Cipher)));
 suite_map_to_openssl_str(#{key_exchange := Kex,
                        cipher := Cipher,
                        mac := aead,
                        prf := PRF}) ->
-    openssl_suite_start(string:to_upper(atom_to_list(Kex))) 
+    openssl_suite_start(string:to_upper(atom_to_list(Kex)), Cipher) 
         ++  openssl_cipher_name(Kex, string:to_upper(atom_to_list(Cipher))) ++
         "-" ++ string:to_upper(atom_to_list(PRF));
 suite_map_to_openssl_str(#{key_exchange := Kex,
                        cipher := Cipher,
                        mac := Mac}) ->
-    openssl_suite_start(string:to_upper(atom_to_list(Kex))) 
+    openssl_suite_start(string:to_upper(atom_to_list(Kex)), Cipher) 
         ++  openssl_cipher_name(Kex, string:to_upper(atom_to_list(Cipher))) ++
         "-" ++ string:to_upper(atom_to_list(Mac)).
 
@@ -148,12 +148,12 @@ suite_openssl_str_to_map("DES-CBC3-SHA") ->
     suite_str_to_map("TLS_RSA_WITH_3DES_EDE_CBC_SHA");
 suite_openssl_str_to_map("SRP-DSS-DES-CBC3-SHA") ->
     suite_str_to_map("TLS_SRP_SHA_DSS_WITH_3DES_EDE_CBC_SHA");
+suite_openssl_str_to_map("EDH-RSA" ++ Rest) ->
+    suite_openssl_str_to_map("DHE-RSA", Rest);
 suite_openssl_str_to_map("DHE-RSA-" ++ Rest) ->
     suite_openssl_str_to_map("DHE-RSA", Rest);
 suite_openssl_str_to_map("DHE-DSS-" ++ Rest) ->
     suite_openssl_str_to_map("DHE-DSS", Rest);
-suite_openssl_str_to_map("EDH-RSA-" ++ Rest) ->
-    suite_openssl_str_to_map("DHE-RSA", Rest);
 suite_openssl_str_to_map("EDH-DSS-" ++ Rest) ->
     suite_openssl_str_to_map("DHE-DSS", Rest);
 suite_openssl_str_to_map("DES" ++ _ = Rest) ->
@@ -980,12 +980,12 @@ suite_bin_to_map(?TLS_AES_128_CCM_SHA256) ->
      #{key_exchange => any,
        cipher => aes_128_ccm,
        mac => aead,
+       prf => sha256};
+suite_bin_to_map(?TLS_AES_128_CCM_8_SHA256) ->
+     #{key_exchange => any,
+       cipher => aes_128_ccm_8,
+       mac => aead,
        prf => sha256}.
-%% suite_bin_to_map(?TLS_AES_128_CCM_8_SHA256) ->
-%%      #{key_exchange => any,
-%%       cipher => aes_128_ccm_8,
-%%        mac => aead,
-%%        prf => sha256}.
 
 %%--------------------------------------------------------------------
 -spec suite_legacy(cipher_suite() | internal_erl_cipher_suite()) -> old_erl_cipher_suite().
@@ -1715,12 +1715,12 @@ suite_map_to_bin(#{key_exchange := any,
       cipher := aes_128_ccm,
       mac := aead,
       prf := sha256}) ->
-    ?TLS_AES_128_CCM_SHA256.
-%% suite_map_to_bin(#{key_exchange := any,
-%%       cipher := aes_128_ccm_8,
-%%       mac := aead,
-%%       prf := sha256}) ->
-%%     ?TLS_AES_128_CCM_8_SHA256.
+    ?TLS_AES_128_CCM_SHA256;
+suite_map_to_bin(#{key_exchange := any,
+      cipher := aes_128_ccm_8,
+      mac := aead,
+      prf := sha256}) ->
+    ?TLS_AES_128_CCM_8_SHA256.
 
 
 tls_1_3_suite_str_to_map(CipherStr) ->
@@ -1838,21 +1838,28 @@ openssl_cipher_name(_, CipherStr) ->
     lists:append(string:replace(CipherStr, "_", "-", all)).
 
 
-openssl_suite_start(Kex) ->
-    case openssl_kex_name(Kex) of
+openssl_suite_start(Kex, Cipher) ->
+    case openssl_kex_name(Kex, Cipher) of
         "" ->
             "";
         Name ->
             Name ++ "-"
     end.
 
-openssl_kex_name("RSA") ->
+openssl_kex_name("RSA", _) ->
     "";
-openssl_kex_name(Kex) ->
+openssl_kex_name("DHE_RSA", Cipher) when Cipher == des_cbc;
+                                         Cipher == '3des_ede_cbc' ->
+    "EDH-RSA";
+openssl_kex_name(Kex, _) ->
     lists:append(string:replace(Kex, "_", "-", all)).
-
 kex_name_from_openssl(Kex) ->
-    lists:append(string:replace(Kex, "-", "_", all)).
+    case lists:append(string:replace(Kex, "-", "_", all)) of
+        "EDH-RSA" ->
+            "DHE_RSA"; 
+        Str  ->
+            Str
+    end.
 
 cipher_name_from_openssl("AES128") ->
     "AES_128_CBC";
@@ -1907,7 +1914,7 @@ openssl_cipher_str_to_algs(_, CipherStr, "POLY1305" = End) ->
     {Cipher, aead, sha256};
 openssl_cipher_str_to_algs(Kex, CipherStr, HashStr) ->
     Hash = algo_str_to_atom(HashStr),
-    Cipher = algo_str_to_atom(cipher_name_from_openssl(CipherStr)),
+    Cipher = algo_str_to_atom(cipher_name_from_openssl(string:strip(CipherStr, left, $-))),
     case openssl_is_aead_cipher(CipherStr) of
         true ->
             {Cipher, aead, Hash};
